pitchtools.calculate_harmonic_diatonic_interval
===============================================

.. autofunction:: abjad.tools.pitchtools.calculate_harmonic_diatonic_interval.calculate_harmonic_diatonic_interval
   :noindex:
